#define BREAKPOINT_VALUE {0x91, 0xd0, 0x20, 0x01}
#define BREAKPOINT_LENGTH 4
#define DECR_PC_AFTER_BREAK 0

#define LT_ELFCLASS     ELFCLASS32
#define LT_ELF_MACHINE  EM_SPARC
#define LT_ELFCLASS2    ELFCLASS32
#define LT_ELF_MACHINE2	EM_SPARC32PLUS

#define PLTs_INIT_BY_HERE NULL
#define E_ENTRY_NAME    "_start"
